==> haskell-mockery-0.3.5-54-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-mockery.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: mockery
version: 0.3.5
id: mockery-0.3.5-BgI4bzxClQEIYQ9vhrplUK
key: mockery-0.3.5-BgI4bzxClQEIYQ9vhrplUK
license: MIT
copyright: (c) 2015-2016 Simon Hengel
maintainer: Simon Hengel <sol@typeful.net>
author: Simon Hengel <sol@typeful.net>
synopsis: Support functions for automated testing
description:
    Support functions for automated testing
category: Testing
abi: a6400373bd34e99fc6c7b8a5d8c4ff48
exposed: True
exposed-modules:
    Test.Mockery.Directory Test.Mockery.Environment
    Test.Mockery.Logging
hidden-modules: Paths_mockery
import-dirs: /usr/lib/ghc-8.6.5/site-local/mockery-0.3.5
library-dirs: /usr/lib/ghc-8.6.5/site-local/mockery-0.3.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/mockery-0.3.5
hs-libraries: HSmockery-0.3.5-BgI4bzxClQEIYQ9vhrplUK
depends:
    base-4.12.0.0 base-compat-0.10.5-FRXoAxOVtbG2qLNIZm1tTr
    bytestring-0.10.8.2 directory-1.3.3.0 filepath-1.4.2.1
    logging-facade-0.3.0-LBaOkuZ7ffa4nMeiudTgFl
    temporary-1.3-5wqvMom531J6cKm3l339v
haddock-interfaces: /usr/share/doc/haskell-mockery/html/mockery.haddock
haddock-html: /usr/share/doc/haskell-mockery/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-mockery-0.3.5-55-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-mockery.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: mockery
version: 0.3.5
id: mockery-0.3.5-6YIvvb663hJLcW5QZCd3qJ
key: mockery-0.3.5-6YIvvb663hJLcW5QZCd3qJ
license: MIT
copyright: (c) 2015-2016 Simon Hengel
maintainer: Simon Hengel <sol@typeful.net>
author: Simon Hengel <sol@typeful.net>
synopsis: Support functions for automated testing
description:
    Support functions for automated testing
category: Testing
abi: 5da8aba337b245dd68142b3c1186537b
exposed: True
exposed-modules:
    Test.Mockery.Directory Test.Mockery.Environment
    Test.Mockery.Logging
hidden-modules: Paths_mockery
import-dirs: /usr/lib/ghc-8.6.5/site-local/mockery-0.3.5
library-dirs: /usr/lib/ghc-8.6.5/site-local/mockery-0.3.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/mockery-0.3.5
hs-libraries: HSmockery-0.3.5-6YIvvb663hJLcW5QZCd3qJ
depends:
    base-4.12.0.0 base-compat-0.10.5-FRXoAxOVtbG2qLNIZm1tTr
    bytestring-0.10.8.2 directory-1.3.3.0 filepath-1.4.2.1
    logging-facade-0.3.0-9lyfdIJElZpHmmjqqRN63X
    temporary-1.3-FE2pFZ9dWIB3eDQ0WTL5GN
haddock-interfaces: /usr/share/doc/haskell-mockery/html/mockery.haddock
haddock-html: /usr/share/doc/haskell-mockery/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
